@@ -1,4 +1,4 @@
 library(testthat)
 library(InSilicoVA)
 
-test_check("InSilicoVA")
+# test_check("InSilicoVA")
